
local ScrW, ScrH = love.graphics.getWidth, love.graphics.getHeight

local sin,cos,atan2,pi = math.sin,math.cos,math.atan2,math.pi

local flr = math.floor

local dsxs = love.graphics.newShader([[	//shader from googlz
	uniform number bs;
	vec4 effect(vec4 color, Image texture, vec2 vTexCoord, vec2 pixel_coords)
	{
		vec4 sum = vec4(0.0);

		sum += texture2D(texture, vec2(vTexCoord.x - 4.0*bs, vTexCoord.y)) * 0.05;
		sum += texture2D(texture, vec2(vTexCoord.x - 3.0*bs, vTexCoord.y)) * 0.09;
		sum += texture2D(texture, vec2(vTexCoord.x - 2.0*bs, vTexCoord.y)) * 0.12;
		sum += texture2D(texture, vec2(vTexCoord.x - bs, vTexCoord.y)) * 0.15;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y)) * 0.16;
		sum += texture2D(texture, vec2(vTexCoord.x + bs, vTexCoord.y)) * 0.15;
		sum += texture2D(texture, vec2(vTexCoord.x + 2.0*bs, vTexCoord.y)) * 0.12;
		sum += texture2D(texture, vec2(vTexCoord.x + 3.0*bs, vTexCoord.y)) * 0.09;
		sum += texture2D(texture, vec2(vTexCoord.x + 4.0*bs, vTexCoord.y)) * 0.05;
		
		return sum;
	}
	]])

local dsys = love.graphics.newShader([[
	uniform number bs;
	vec4 effect(vec4 color, Image texture, vec2 vTexCoord, vec2 pixel_coords)
	{
		vec4 sum = vec4(0.0);

		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y - 4.0*bs)) * 0.05;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y - 3.0*bs)) * 0.09;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y - 2.0*bs)) * 0.12;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y- bs)) * 0.15;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y)) * 0.16;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y + bs)) * 0.15;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y + 2.0*bs)) * 0.12;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y + 3.0*bs)) * 0.09;
		sum += texture2D(texture, vec2(vTexCoord.x, vTexCoord.y + 4.0*bs)) * 0.05;

		return sum;
	}
	]])

function hsv( h, s, v, a )	--https://github.com/EmmanuelOga/columns/blob/master/utils/color.lua (LICENSE: http://creativecommons.org/licenses/by/3.0/legalcode)
	h=h/360

	local i = flr(h * 6);
	local f = h * 6 - i;
	local p = v * (1 - s);
	local q = v * (1 - f * s);
	local t = v * (1 - (1 - f) * s);

	i = i % 6

	if i == 0 then r, g, b = v, t, p
	elseif i == 1 then r, g, b = q, v, p
	elseif i == 2 then r, g, b = p, v, t
	elseif i == 3 then r, g, b = p, q, v
	elseif i == 4 then r, g, b = t, p, v
	elseif i == 5 then r, g, b = v, p, q
	end

	return {r* 255, g* 255, b* 255, (a or 1) * 255}
end

function hsfail( h, s, v, a )	--https://github.com/EmmanuelOga/columns/blob/master/utils/color.lua (LICENSE: http://creativecommons.org/licenses/by/3.0/legalcode)
	h=(h/360)%360

	return {((sin(h*pi*(2/3))+1)/2)*255, ((sin(h*pi*(4/3))+1)/2)*255, ((sin(h*pi*2)+1)/2)*255, (a or 1) * 255}

end

local time = love.timer.getTime

function rotp(s,p,r)
	local c = ((120*p+r)/180)*pi
	--local c = ((r)/180)*pi
	return cos(c)*s, sin(c)*s
end

function tri(size,phase,n,add)

	local cx,cy = ScrW()/2, ScrH()/2

	local odd = (n%2)*60

	--local vt = {

		local pp1 = (phase*3) + 1

		local a,b = rotp(size*pp1+add,phase,odd)
		local c,d = rotp(size*pp1+add,phase,120+odd)
		local e,f = rotp(size*pp1+add,phase,240+odd)
	--}

	love.graphics.polygon( "line", cx+a,cy+b,cx+c,cy+d,cx+e,cy+f )

end

local color = love.graphics.setColor
local cnvs = love.graphics.newCanvas(ScrW(),ScrH(),"rgba32f")
local cnvs2 = love.graphics.newCanvas(ScrW(),ScrH(),"rgba32f")
local cnvs3 = love.graphics.newCanvas(ScrW(),ScrH(),"rgba32f")

local lph = 0
local phc = 0

function love.update(dt)
	--p  = love.timer.getTime()
end

print("I've heard triangles are the strongest figure. How about triangles supported by triangles?")

function love.draw()
	local phase = time()/2 % 1
	
	if lph > phase then
		phc = phc + 1

	end

	lph = phase

	dsxs:send("bs", 4/ScrW())
	dsys:send("bs", 4/ScrH())

	color(255,255,255,255)
	love.graphics.setCanvas(cnvs2)
		love.graphics.setShader(dsxs)
		love.graphics.draw(cnvs)
		love.graphics.setShader()
	love.graphics.setCanvas()

	love.graphics.setCanvas(cnvs3)
		love.graphics.setShader(dsys)
		love.graphics.draw(cnvs2)
		love.graphics.setShader()
	love.graphics.setCanvas()

	dsxs:send("bs", 1/ScrW())
	dsys:send("bs", 1/ScrH())

	love.graphics.setCanvas(cnvs2)
		love.graphics.setShader(dsxs)
		love.graphics.draw(cnvs)
		love.graphics.setShader()
	love.graphics.setCanvas()

	love.graphics.setCanvas(cnvs3)
		love.graphics.setShader(dsys)
		love.graphics.draw(cnvs2)
		love.graphics.setShader()
	love.graphics.setCanvas()

	love.graphics.draw(cnvs3)

	love.graphics.setCanvas(cnvs)
		for I = 0, (flr(math.log(math.max(ScrW(),ScrH())*2,2))+4) do
			love.graphics.setCanvas(cnvs)
			color(hsfail(((I+phc)%100)*120+360*phase,1,1,1))
			for J = 0, 6 do
				tri((2^I)/10,phase,I,-J)
			end
			love.graphics.setCanvas()

			color(hsfail(((I+phc)%100)*120+360*phase,1,1,1))
			for J = 0, 6 do
				tri((2^I)/10,phase,I,-J)
			end
		end
	love.graphics.setCanvas()
end
